@@ -36,7 +36,7 @@ class BaseMsg(BaseModel):
     # 消息接收者应用编码
     app_code: str = None
     # 消息类型（控制消息：ACT；数据消息：DATA；流式数据消息：STREAM）
-    msg_type: MsgType
+    msg_type: Union[str, MsgType]
     # 消息体
     msg_body: Union[str, Dict, List] = None
     # 产生时间戳
